@@ -8,13 +8,14 @@ test_that("AutoTuner / train+predict", {
   expect_learner(at)
   at$train(task)
   expect_learner(at)
-  expect_equal(at$learner$param_set$values, list(xval = 0, cp = 0.2))
+
+  expect_equal(sortnames(at$learner$param_set$values), list(xval = 0, cp = 0.2))
   inst = at$tuning_instance
   a = at$archive$data
   expect_data_table(a, nrows = 3L)
   r = at$tuning_result
   expect_equal(r$x_domain[[1]], list(cp = 0.2))
-  expect_equal(r$learner_param_vals[[1]], list(xval = 0, cp = 0.2))
+  expect_equal(sortnames(r$learner_param_vals[[1]]), list(xval = 0, cp = 0.2))
   prd = at$predict(task)
   expect_prediction(prd)
   expect_s3_class(at$learner$model, "rpart")
@@ -39,11 +40,12 @@ test_that("AutoTuner / resample", {
 
   rr = resample(tsk("iris"), at, r_outer, store_models = TRUE)
 
+
   # check tuning results of all outer folds
   expect_equal(length(rr$learners), outer_folds)
   lapply(rr$learners, function(ll) {
     assert_r6(ll, "AutoTuner")
-    expect_equal(ll$learner$param_set$values, list(xval = 0, cp = 0.2))
+    expect_equal(sortnames(ll$learner$param_set$values), list(xval = 0, cp = 0.2))
     inst = ll$tuning_instance
     assert_r6(inst, "TuningInstanceSingleCrit")
     expect_data_table(inst$archive$data, nrows = inner_evals)
@@ -56,9 +58,9 @@ test_that("nested resamppling results are consistent ", {
   # https://github.com/mlr-org/mlr3/issues/428
   # this resulted in different tuning results stored in models than used in final training
 
-  ps = ParamSet$new(list(
-    ParamDbl$new("cp", lower = 0.001, upper = 0.1),
-    ParamInt$new("minsplit", lower = 1, upper = 10)))
+  ps = ps(
+    cp = p_dbl(lower = 0.001, upper = 0.1),
+    minsplit = p_int(lower = 1, upper = 10))
 
 
   lrn = AutoTuner$new(
@@ -99,9 +101,9 @@ test_that("AutoTuner works with graphlearner", {
   task = tsk("iris")
   ms = MeasureDummyCPClassif$new(fun = function(pv) if (pv$classif.rpart.cp == 0.2) 0 else 1)
   te = trm("evals", n_evals = 4)
-  ps = ParamSet$new(list(
-    ParamDbl$new("classif.rpart.cp", lower = 0.1, upper = 0.3)
-  ))
+  ps = ps(
+    classif.rpart.cp = p_dbl(lower = 0.1, upper = 0.3)
+  )
   tuner = tnr("grid_search", resolution = 3)
   at = AutoTuner$new(
     learner = gl,
@@ -136,9 +138,9 @@ test_that("Nested resampling works with graphlearner", {
   task = tsk("iris")
   ms = MeasureDummyCPClassif$new(fun = function(pv) if (pv$classif.rpart.cp == 0.2) 0 else 1)
   te = trm("evals", n_evals = 4)
-  ps = ParamSet$new(list(
-    ParamDbl$new("classif.rpart.cp", lower = 0.1, upper = 0.3)
-  ))
+  ps = ps(
+    classif.rpart.cp = p_dbl(lower = 0.1, upper = 0.3)
+  )
   tuner = tnr("grid_search", resolution = 3)
   at = AutoTuner$new(
     learner = gl,
@@ -258,9 +260,9 @@ test_that("search space from TuneToken works", {
   at$train(tsk("iris"))
   expect_equal(at$tuning_instance$search_space$ids(), "cp")
 
-  ps = ParamSet$new(list(
-    ParamDbl$new("cp", lower = 0.1, upper = 0.3)
-  ))
+  ps = ps(
+    cp = p_dbl(lower = 0.1, upper = 0.3)
+  )
 
   expect_error(AutoTuner$new(learner = learner, resampling = rsmp("holdout"),
     measure = msr("classif.ce"), terminator = trm("evals", n_evals = 1),
