@@ -3,9 +3,9 @@ skip_if_not_installed("GenSA")
 test_that("TunerGenSA", {
   test_tuner("gensa")
 
-  ps = ParamSet$new(params = list(
-    ParamLgl$new("save_tasks")
-  ))
+  ps = ps(
+    save_tasks = p_lgl()
+  )
   te = trm("evals", n_evals = 2)
   inst = TuningInstanceSingleCrit$new(tsk("iris"), lrn("classif.debug"), rsmp("holdout"), msr("classif.ce"), te, ps)
   tt = TunerGenSA$new()
@@ -13,14 +13,10 @@ test_that("TunerGenSA", {
 })
 
 test_that("TunerGenSA with int params and trafo", {
-  ps = ParamSet$new(params = list(
-    ParamDbl$new("cp", lower = 0.001, upper = 0.1),
-    ParamDbl$new("minsplit", lower = 1, upper = 10)
-  ))
-  ps$trafo = function(x, param_set) {
-    x$minsplit = as.integer(round(x$minsplit))
-    return(x)
-  }
+  ps = ps(
+    cp = p_dbl(lower = 0.001, upper = 0.1),
+    minsplit = p_dbl(lower = 1, upper = 10, trafo = function(x) as.integer(round(x)))
+  )
   te = trm("evals", n_evals = 2)
   inst = TuningInstanceSingleCrit$new(tsk("iris"), lrn("classif.rpart"), rsmp("holdout"), msr("classif.ce"), te, ps)
   tt = TunerGenSA$new()
