@@ -88,10 +88,10 @@ test_that("tuning with custom resampling", {
 
   learner = lrn("classif.rpart")
   measure = msr("classif.ce")
-  tune_ps = ParamSet$new(list(
-    ParamDbl$new("cp", lower = 0.001, upper = 0.1),
-    ParamInt$new("minsplit", lower = 1, upper = 10)
-  ))
+  tune_ps = ps(
+    cp = p_dbl(lower = 0.001, upper = 0.1),
+    minsplit = p_int(lower = 1, upper = 10)
+  )
   terminator = trm("evals", n_evals = 10)
   tuner = tnr("random_search")
 
@@ -116,12 +116,13 @@ test_that("non-scalar hyperpars (#201)", {
 
   learner = mlr3pipelines::po("select") %>>% lrn("classif.rpart")
 
-  search_space = ParamSet$new(list(
-    ParamInt$new("classif.rpart.minsplit", 1, 1)))
-  search_space$trafo = function(x, param_set) {
-    x$select.selector = mlr3pipelines::selector_all()
-    return(x)
-  }
+  search_space = ps(
+    classif.rpart.minsplit = p_int(1, 1),
+    .extra_trafo = function(x, param_set) {
+      x$select.selector = mlr3pipelines::selector_all()
+      return(x)
+    }
+  )
 
   inst = TuningInstanceSingleCrit$new(tsk("iris"), learner, rsmp("holdout"),
     msr("classif.ce"), trm("evals", n_evals = 1), search_space,
@@ -160,10 +161,10 @@ test_that("store_benchmark_result and store_models flag works", {
 test_that("check_values flag with parameter set dependencies", {
   learner = LearnerRegrDepParams$new()
   learner$param_set$values$xx = "a"
-  search_space = ParamSet$new(list(
-    ParamDbl$new("cp", lower = 0.1, upper = 0.3),
-    ParamDbl$new("yy", lower = 0.1, upper = 0.3)
-  ))
+  search_space = ps(
+    cp = p_dbl(lower = 0.1, upper = 0.3),
+    yy = p_dbl(lower = 0.1, upper = 0.3)
+  )
   terminator = trm("evals", n_evals = 20)
   tuner = tnr("random_search")
 
@@ -176,7 +177,7 @@ test_that("check_values flag with parameter set dependencies", {
     rsmp("holdout"), msr("regr.mse"), terminator, search_space,
     check_values = TRUE)
   expect_error(tuner$optimize(inst),
-    regexp = "The parameter 'yy' can only be set")
+    regexp = "yy.* can only be set")
 })
 
 test_that("search space from TuneToken works", {
@@ -190,9 +191,9 @@ test_that("search space from TuneToken works", {
   expect_r6(instance$search_space, "ParamSet")
   expect_equal(instance$search_space$ids(), "cp")
 
-  ps = ParamSet$new(list(
-    ParamDbl$new("cp", lower = 0.1, upper = 0.3)
-  ))
+  ps = ps(
+    cp = p_dbl(lower = 0.1, upper = 0.3)
+  )
 
   expect_error(TuningInstanceSingleCrit$new(task = tsk("iris"), learner = learner,
     resampling = rsmp("holdout"), measure = msr("classif.ce"),
@@ -360,7 +361,7 @@ test_that("assign_result works with no hyperparameters and two constant", {
   res = instance$result
   expect_data_table(res, nrows = 1)
   expect_equal(res$classif.ce, 0.8)
-  expect_equal(res$learner_param_vals[[1]], list(xval = 1, cp = 1))
+  expect_equal(sortnames(res$learner_param_vals[[1]]), list(xval = 1, cp = 1))
 })
 
 test_that("assign_result works with one hyperparameters and one constant", {
